@@ -126,7 +126,7 @@ compare_means <- function(formula, data, method = "wilcox.test",
 
   if(!.is_empty(group)){
     group.vals <- .select_vec(data, group)
-    if(!is.factor(group.vals)) data[, group] <- factor(group.vals, levels = unique(group.vals))
+    if(!is.factor(group.vals)) data[[group]] <- factor(group.vals, levels = unique(group.vals))
   }
 
   # Keep only variables of interest
@@ -140,9 +140,8 @@ compare_means <- function(formula, data, method = "wilcox.test",
   #:::::::::::::::::::::::::::::::::::::::::::::::::::::
   # ex: formula = c(GATA3, XBP1, DEPDC1) ~ group
   if(.is_multi_formula(formula)){
-    data <- tidyr::gather_(data, key_col = ".y.", value_col = ".value.",
-                           gather_cols =  variables)
-    data$.y. <- factor(data$.y., levels = unique(data$.y.))
+    data <- df_gather(data, cols = variables, names_to = ".y.", values_to = ".value.") %>%
+      dplyr::mutate(.y. = factor(.data$.y., levels = unique(.data$.y.)))
     response.var <- ".value."
     group.by = c(group.by,  ".y.")
     formula <- .collapse(response.var, group, sep = " ~ ") %>% stats::as.formula()
@@ -157,7 +156,7 @@ compare_means <- function(formula, data, method = "wilcox.test",
     else group.levs <- unique(group.vals)
 
     if(ref.group %in% group.levs){
-      data[, group] <- stats::relevel(group.vals, ref.group)
+      data[[group]] <- stats::relevel(group.vals, ref.group)
     }
 
     if(ref.group == ".all."){
@@ -167,10 +166,9 @@ compare_means <- function(formula, data, method = "wilcox.test",
       # Create a new grouping column gathering group and the .all. columns
       .group.name. <- NULL
       data <- data %>%
-        tidyr::gather_(key_col = ".group.name.", value_col = ".group.",
-               gather_cols = c(".group.", ".all.")) %>%
+        df_gather(cols = c(".group.", ".all."), names_to =  ".group.name.", values_to = ".group.") %>%
         dplyr::select(-.group.name.)
-      data$.group. <- factor(data$.group., levels = c(".all.", group.levs))
+      data[[".group."]] <- factor(data[[".group."]], levels = c(".all.", group.levs))
       group <- ".group."
       formula <- .collapse(response.var, group, sep = " ~ ") %>% stats::as.formula()
 
@@ -286,6 +284,8 @@ compare_means <- function(formula, data, method = "wilcox.test",
     test.opts <- list(x = .select_vec(data, x), ...)
   else test.opts <- list(formula = formula, data = data, ...)
 
+  if(method == "wilcox.test" && is.null(test.opts$exact)) test.opts$exact <- FALSE
+
   res <- data.frame(p = suppressWarnings(do.call(test, test.opts)$p.value))
   group1 <- group2 <- NULL
 
@@ -330,7 +330,7 @@ compare_means <- function(formula, data, method = "wilcox.test",
                     g = .select_vec(data, group),
                     paired = paired,
                     ...)
-  # if(method == "pairwise.wilcox.test") test.opts$exact <- FALSE
+  if(method == "pairwise.wilcox.test" && is.null(test.opts$exact)) test.opts$exact <- FALSE
   if(method == "pairwise.t.test"){
     if(missing(pool.sd)){
       if(!paired) pool.sd <- FALSE
@@ -340,11 +340,11 @@ compare_means <- function(formula, data, method = "wilcox.test",
 
   pvalues <- suppressWarnings(do.call(test, test.opts)$p.value) %>%
     as.data.frame()
-  group1 <- group2 <- p <- NULL
-  pvalues$group2 <- rownames(pvalues)
+  ..group1.. <- ..group2.. <- p <- NULL
+  pvalues$..group2.. <- rownames(pvalues)
   pvalues <- pvalues %>%
-    tidyr::gather(key = "group1", value = "p", -group2) %>%
-    dplyr::select(group1, group2, p) %>%
+    tidyr::gather(key = "..group1..", value = "p", -..group2..) %>%
+    dplyr::select(group1 = ..group1.., group2 = ..group2.., p) %>%
     dplyr::filter(!is.na(p))
   pvalues
 }
@@ -399,9 +399,9 @@ compare_means <- function(formula, data, method = "wilcox.test",
   variables <- .formula_left_variables(formula)
   group <- .formula_right_variables(formula)
 
-  data <- tidyr::gather_(data, key_col = ".y.", value_col = ".value.",
-                         gather_cols =  variables)
-  data$.y. <- factor(data$.y., levels = unique(data$.y.))
+  data <- data %>%
+    df_gather(cols = variables, names_to = ".y.", values_to = ".value.") %>%
+    dplyr::mutate(.y. = factor(.data$.y., levels = unique(.data$.y.)))
   formula <- .collapse(".value.", group, sep = " ~ ") %>% stats::as.formula()
   group.by = c(group.by, ".y.")
 
